{******************************************}
{ FlexReport VCL Register Unit             }
{    Copyright (c) IO International Co.    }
{    All Rights Reserved                   }
{            Programed by Seo Hyung Su.    }
{******************************************}

unit Flexreg;

{$D-,L-,S-}

interface

{ Register custom useful controls }

procedure Register;

implementation

{$IFDEF WIN32}
{$R *.D32}
{$ELSE}
{$R *.D16}
{$ENDIF}

uses Windows, Classes, SysUtils, Forms, Dialogs, DsgnIntf,

     FlexVarDlg, FlexReport, FlexAbout;


{ TFilenameProperty
  Property editor for the TFlexReport.  Displays an File Open Dialog
  for the name of the FlexReport file.}

type
  TFilenameProperty = class(TStringProperty)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
  end;

{ TFilenameProperty }

procedure TFileNameProperty.Edit;
var
  FlexFileOpen: TOpenDialog;
begin
  FlexFileOpen := TOpenDialog.Create(Application);
  FlexFileOpen.FileName := GetValue;
  FlexFileOpen.Filter := 'FlexReport files (*.frp)|*.frp|All files (*.*)|*.*';
  FlexFileOpen.Options := FlexFileOpen.Options + [ofShowHelp, ofPathMustExist,
    ofFileMustExist];
  try
    if FlexFileOpen.Execute then SetValue(FlexFileOpen.FileName);
  finally
    FlexFileOpen.Free;
  end;
end;

function TFilenameProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog, paRevertable];
end;

{ TFlexDesignModeMenu }
type
  TFlexDesignModeMenu = Class(TComponentEditor)
  private
    FFlexReport: TFlexReport;
  public
    constructor Create(AComponent: TComponent; ADesigner: TFormDesigner); override;
    procedure Edit; override;
    procedure ExecuteVerb(Index: integer); override;
    function GetVerb(Index: integer): string; override;
    function GetVerbCount : integer; override;
  end;

constructor TFlexDesignModeMenu.Create(AComponent: TComponent; ADesigner: TFormDesigner);
begin
  inherited Create(AComponent, ADesigner);
  FFlexReport := TFlexReport(AComponent);
end;

procedure TFlexDesignModeMenu.Edit;
begin
  ShowFlexVariables(FFlexReport.VarList);
end;

function TFlexDesignModeMenu.GetVerb(Index: integer): string;
begin
  case Index of
    0: Result := '&Copyright IO International';
    1: Result := '-';
    2: Result := '&About FlexReport';
    3: Result := 'View Report &Variables...';
    4: Result := '-';
    5: Result := 'Run Flex&Run...';
    6: Result := 'Run &FlexReport...';
  end
end;

function TFlexDesignModeMenu.GetVerbCount : integer;
begin
  Result := 7;
end;

procedure TFlexDesignModeMenu.ExecuteVerb(Index: integer);
var
  CmdLine: string;
begin
  case Index of
    0, 2 : with TFrmAbout.Create(Application) do ShowModal;
    3 : ShowFlexVariables(FFlexReport.VarList);
    5 :
      if FFlexReport.FileName <> '' then begin
        CmdLine := FFlexReport.FlexRunPath + ' -v ' + FFlexReport.FileName;
        WinExec(PChar(CmdLine), SW_SHOWNORMAL);
      end;
    6 : WinExec(PChar(FFlexReport.FlexReportPath), SW_SHOWNORMAL);
  end;
end;

procedure Register;
begin
  RegisterComponents('HC Controls', [TFlexReport]);
  RegisterPropertyEditor(TypeInfo(TFileName), TFlexReport, 'FileName', TFileNameProperty);
  RegisterComponentEditor(TFlexReport, TFlexDesignModeMenu);
end;

end.
